﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace VezLego
{
    public partial class KresleniForm : Form
    {
        private StavebniPlan plan;

        public KresleniForm(StavebniPlan plan)
        {
            InitializeComponent();
            this.plan = plan;
            lbPouzite.DataSource = plan.Specifikace();
            lX.Text = plan.X.ToString();
            lY.Text = plan.Y.ToString();
            lTyp.Text = plan.Typ.ToString();
            lbPatra.DataSource = plan.Patra;
        }

        private void pictureBox1_Paint(object sender, PaintEventArgs e)
        {
            Graphics g = e.Graphics;
            Patro patro = (Patro)lbPatra.SelectedItem;
            int stranaKostky = Math.Min(pbPlatno.Width, pbPlatno.Height) / Math.Max(plan.X, plan.Y);
            foreach (KostkaPatra k in patro.Kostky)
            {
                g.FillRectangle(new Pen(k.Barva).Brush, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                    k.Sirka * stranaKostky, k.Delka * stranaKostky);
                g.DrawRectangle(Pens.Black, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                    k.Sirka * stranaKostky, k.Delka * stranaKostky);
            }
        }

        private void lbPatra_SelectedIndexChanged(object sender, EventArgs e)
        {
            pbPlatno.Refresh();
        }

        private void pbPohledy_Paint(object sender, PaintEventArgs e)
        {
            var vsechnyKostky = plan.Patra.SelectMany(p => p.Kostky);
            Graphics g = e.Graphics;
            int stranaKostky = 30;
            if (rbPredu.Checked)
            {
                var predni = vsechnyKostky.Where(k => k.Y == 1);
                foreach (KostkaPatra k in predni)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.X - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Sirka * stranaKostky, stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.X - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Sirka * stranaKostky, stranaKostky); 
                }
            }
            else if (rbZadu.Checked)
            {
                var zadni = vsechnyKostky.Where(k => (k.Y + k.Delka) == plan.Y + 1);
                foreach (KostkaPatra k in zadni)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.X - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Sirka * stranaKostky, stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.X - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Sirka * stranaKostky, stranaKostky);
                }    
            }
            else if (rbShora.Checked)
            {
                foreach (KostkaPatra k in plan.Patra[plan.Patra.Count - 1].Kostky)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                        k.Sirka * stranaKostky, k.Delka * stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                        k.Sirka * stranaKostky, k.Delka * stranaKostky);
                }    
            }
            else if (rbSpoda.Checked)
            {
                foreach (KostkaPatra k in plan.Patra[0].Kostky)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                        k.Sirka * stranaKostky, k.Delka * stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.X - 1) * stranaKostky, (k.Y - 1) * stranaKostky,
                        k.Sirka * stranaKostky, k.Delka * stranaKostky);
                } 
            }
            else if (rbLeva.Checked)
            {
                var leve = vsechnyKostky.Where(k => k.X == 1);
                foreach (KostkaPatra k in leve)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.Y - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Delka * stranaKostky, stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.Y - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Delka * stranaKostky, stranaKostky);
                }
            }
            else
            {
                var prave = vsechnyKostky.Where(k => k.X + k.Sirka == plan.X + 1 || k.X == plan.X + 1);
                foreach (KostkaPatra k in prave)
                {
                    g.FillRectangle(new Pen(k.Barva).Brush, (k.Y - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Delka * stranaKostky, stranaKostky);
                    g.DrawRectangle(Pens.Black, (k.Y - 1) * stranaKostky, (k.Patro - 1) * stranaKostky,
                        k.Delka * stranaKostky, stranaKostky);
                }
            }
        }

        private void rb_Chabged(object sender, EventArgs e)
        {
            pbPohledy.Refresh();
        }
    }
}
