﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace VezLego
{
    public class StavebniPlan
    {
        public int X { get; private set; }
        public int Y { get; private set; }
        public TypVeze Typ { get; private set; }
        public List<Patro> Patra { get; private set; }

        public StavebniPlan(int x, int y, TypVeze typ, List<Patro> patra)
        {
            X = x;
            Y = y;
            Typ = typ;
            Patra = patra;
        }

        public static StavebniPlan Parsuj(string soubor)
        {
            string[] radky = File.ReadAllLines(soubor);
            var barvy = SpecifikaceVeze.DefinujBarvy();
            int x = 0, y = 0;
            TypVeze typ = TypVeze.D;
            List<KostkaPatra> kostky = new List<KostkaPatra>();
            for (int i = 0; i < radky.Length; i++)
            {
                if (!string.IsNullOrEmpty(radky[i]))
                {
                    string[] hodnoty = radky[i].Split(new char[] { ' ' }, StringSplitOptions.RemoveEmptyEntries);
                    if (i == 0)
                    {
                        x = int.Parse(hodnoty[0]);
                        y = int.Parse(hodnoty[1]);
                        typ = (TypVeze)Enum.Parse(typeof(TypVeze), hodnoty[2]);
                    }
                    else
                    {
                        int patro = int.Parse(hodnoty[0]);
                        int xk = int.Parse(hodnoty[1]);
                        int yk = int.Parse(hodnoty[2]);
                        Color barva = barvy[hodnoty[3][0]];
                        string[] rozmery = hodnoty[4].Split('x');
                        int sirka = int.Parse(rozmery[0]);
                        int delka = int.Parse(rozmery[1]);
                        kostky.Add(new KostkaPatra(xk, yk, patro, barva, sirka, delka));
                    }
                }
            }
            List<Patro> patra = (from k in kostky
                        group k by k.Patro into p
                         select new Patro(p.Key, p.ToList())).ToList();
            return new StavebniPlan(x, y, typ, patra); 
        }

        public List<KostkaSpecifikace> Specifikace()
        {
            var vse = Patra.SelectMany(p => p.Kostky);
            var skupiny = from k in vse
                          group k by new { k.Barva, k.Plocha, k.Sirka, k.Delka } into stejne
                          select new KostkaSpecifikace(stejne.Key.Barva, stejne.Count(), stejne.Key.Sirka, stejne.Key.Delka);
            return skupiny.ToList();
        }
    }
}
